@@ -6,10 +6,10 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#
 #     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
+#
 # Unless required by applicable law or agreed to in writing,
 # software distributed under the License is distributed on an
 # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,15 +18,9 @@
 # under the License.
 
 from aliyunsdkcore.request import RoaRequest
-from aliyunsdkcs.endpoint import endpoint_data
-
 class DescribeApiVersionRequest(RoaRequest):
 
 	def __init__(self):
 		RoaRequest.__init__(self, 'CS', '2015-12-15', 'DescribeApiVersion')
 		self.set_uri_pattern('/version')
-		self.set_method('GET')
-		if hasattr(self, "endpoint_map"):
-			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
-		if hasattr(self, "endpoint_regional"):
-			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+		self.set_method('GET')
\ No newline at end of file
